from django.apps import AppConfig


class FrancedataConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "francedata"
